@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,7 +16,8 @@ from __future__ import unicode_literals
 import sys
 import os
 
-from PyQt5.QtCore import QDir, QLibraryInfo, QByteArray
+from PyQt5.QtCore import (QDir, QLibraryInfo, QByteArray,
+                          QCoreApplication, QT_VERSION_STR)
 
 # names of the various settings objects
 settingsNameOrganization = "Eric6"
@@ -27,6 +28,7 @@ settingsNameRecent = "eric6recent"
 recentNameMultiProject = "MultiProjects"
 recentNameProject = "Projects"
 recentNameFiles = "Files"
+recentNameHexFiles = "HexFiles"
 recentNameHosts = "Hosts6"
 
 configDir = None
@@ -211,6 +213,20 @@ def getQtBinariesPath():
     return QDir.toNativeSeparators(path)
 
 
+def translate(*args):
+    """
+    Module function to handle different PyQt 4/5 QCoreApplication.translate
+    parameter.
+    
+    @param args tuple of arguments from QCoreApplication.translate (tuple)
+    @return translated string (string)
+    """
+    if QT_VERSION_STR.startswith('4'):
+        args = list(args)
+        args.insert(3, QCoreApplication.CodecForTr)
+    return QCoreApplication.translate(*args)
+
+
 ###############################################################################
 ## functions for searching a Python2/3 interpreter
 ###############################################################################
@@ -255,6 +271,35 @@ def findPythonInterpreters(pyVersion):
     return interpreters
 
 
+###############################################################################
+## functions for extended string handling
+###############################################################################
+
+
+def strGroup(txt, sep, groupLen=4):
+    """
+    Module function to group a string into sub-strings separated by a
+    separator.
+    
+    @param txt text to be grouped
+    @type str
+    @param sep separator string
+    @type str
+    @param groupLen length of each group
+    @type int
+    @return result string
+    @rtype str
+    """
+    groups = []
+    
+    while len(txt) // groupLen != 0:
+        groups.insert(0, txt[-groupLen:])
+        txt = txt[:-groupLen]
+    if len(txt) > 0:
+        groups.insert(0, txt)
+    return sep.join(groups)
+
+
 ###############################################################################
 ## functions for converting QSetting return types to valid types
 ###############################################################################
@@ -314,3 +359,6 @@ def toDict(value):
         return {}
     else:
         return value
+
+#
+# eflag: noqa = M801
